//! All objects related to artist defined by Spotify API

use serde::{Deserialize, Serialize};

use crate::{CursorBasedPage, Followers, Image, SpotifyId};

/// Simplified Artist Object
#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq, Default)]
pub struct SimplifiedArtist {
    pub href: Option<String>,
    #[serde(with = "crate::spotify_id::ser::artist::option")]
    pub id: Option<SpotifyId>,
    pub name: String,
}

/// Full Artist Object
#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
pub struct FullArtist {
    pub followers: Followers,
    pub genres: Vec<String>,
    pub href: String,
    #[serde(with = "crate::spotify_id::ser::artist")]
    pub id: SpotifyId,
    pub images: Vec<Image>,
    pub name: String,
    pub popularity: u32,
}

/// Intermediate full artist object wrapped by `Vec`
#[derive(Deserialize)]
pub struct FullArtists {
    pub artists: Vec<FullArtist>,
}

/// Intermediate full Artists vector wrapped by cursor-based-page object
#[derive(Deserialize)]
pub struct CursorPageFullArtists {
    pub artists: CursorBasedPage<FullArtist>,
}
