use std::fmt;

use data_encoding::HEXLOWER_PERMISSIVE;

use crate::{spotify_id::to_base16, IdError};

#[derive(Copy, Clone, PartialEq, Eq, PartialOrd, Ord, Hash)]
pub struct FileId(pub [u8; 20]);

impl FileId {
    pub fn from_raw(src: &[u8]) -> Result<FileId, IdError> {
        let mut dst = [0u8; 20];
        if src.len() != 20 {
            return Err(IdError::InvalidId);
        }
        dst.clone_from_slice(src);
        Ok(FileId(dst))
    }

    pub fn from_base16(src: &str) -> Result<FileId, IdError> {
        let mut dst = [0u8; 20];
        HEXLOWER_PERMISSIVE
            .decode_mut(src.as_bytes(), &mut dst)
            .map_err(|_| IdError::InvalidId)?;
        Ok(FileId(dst))
    }

    #[allow(clippy::wrong_self_convention)]
    pub fn to_base16(&self) -> Result<String, IdError> {
        to_base16(&self.0, &mut [0u8; 40])
    }
}

impl fmt::Debug for FileId {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        f.debug_tuple("FileId").field(&self.to_base16()).finish()
    }
}

impl fmt::Display for FileId {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        f.write_str(&self.to_base16().unwrap_or_default())
    }
}

impl TryFrom<&[u8]> for FileId {
    type Error = IdError;

    fn try_from(value: &[u8]) -> Result<Self, Self::Error> {
        Self::from_raw(value)
    }
}
