//! All Spotify API endpoint response objects. Please refer to the endpoints
//! where they are used for a link to their reference in the Spotify API
//! documentation.
mod album;
mod artist;
mod audio;
mod category;
mod context;
pub(crate) mod custom_serde;
mod device;
mod enums;
mod error;
mod file_id;
mod image;
mod offset;
mod page;
mod playing;
mod playlist;
mod recommend;
mod search;
mod show;
mod spotify_id;
mod track;
mod user;

pub use {
    album::*, artist::*, audio::*, category::*, context::*, device::*, enums::*, error::*,
    file_id::*, image::*, offset::*, page::*, playing::*, playlist::*, recommend::*, search::*,
    show::*, spotify_id::*, track::*, user::*,
};

use serde::{Deserialize, Serialize};

/// Followers object
#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq, Default)]
pub struct Followers {
    // This field will always set to null, as the Web API does not support it at the moment.
    // pub href: Option<String>,
    pub total: u32,
}

/// A full track object or a full episode object
#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
#[serde(untagged)]
pub enum PlayableItem {
    Track(track::FullTrack),
    Episode(show::FullEpisode),
}

impl PlayableItem {
    /// Utility to get the ID from either variant in the enum.
    ///
    /// Note that if it's a track and if it's local, it may not have an ID, in
    /// which case this function will return `None`.
    #[must_use]
    pub fn id(&self) -> Option<&SpotifyId> {
        match self {
            PlayableItem::Track(t) => t.id.as_ref(),
            PlayableItem::Episode(e) => Some(&e.id),
        }
    }
}
