//! All kinds of user object

use serde::{Deserialize, Serialize};

use crate::{Country, Followers, Image, SpotifyId, SubscriptionLevel};

/// Public user object
#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
pub struct PublicUser {
    pub display_name: Option<String>,
    pub followers: Option<Followers>,
    pub href: String,
    #[serde(with = "crate::spotify_id::ser::user")]
    pub id: SpotifyId,
    #[serde(default = "Vec::new")]
    pub images: Vec<Image>,
}

/// Private user object
#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
pub struct PrivateUser {
    pub country: Option<Country>,
    pub display_name: Option<String>,
    pub email: Option<String>,
    pub explicit_content: Option<ExplicitContent>,
    pub followers: Option<Followers>,
    pub href: String,
    #[serde(with = "crate::spotify_id::ser::user")]
    pub id: SpotifyId,
    pub images: Option<Vec<Image>>,
    pub product: Option<SubscriptionLevel>,
}

/// Explicit content setting object
#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq, Default)]
pub struct ExplicitContent {
    pub filter_enabled: bool,
    pub filter_locked: bool,
}
